# -*- coding: utf-8 -*-
# Description: mod_tile netdata python.d module
# Author: Didier Fabert (tartare)

from base import UrlService

try:
    from urlparse import urlparse
except ImportError:
    from urllib.parse import urlparse

# default module values (can be overridden per job in `config`)
# update_every = 2
priority = 60000
retries = 60

ACCESS_INFO = [
]

# charts order (can be overridden if you want less charts, or different order)
ORDER = ['responses', 'cache', 'zoom']

CHARTS = {
    'responses': {
        'options': [None, "Number of HTTP response codes", "Responces", "number", "mod_tile.reponses", "line"],
        'lines': [
            ['NoResp200', '200'],
            ['NoResp304', '304'],
            ['NoResp404', '404'],
            ['NoResp503', '503'],
            ['NoResp5XX', '5xx'],
            ['NoRespOther', 'Other']
        ]},
    'cache': {
        'options': [None, "Tiles cached/rendered", "Tiles", "cache and render", "mod_tile.cache.render", "line"],
        'lines': [
            ['NoFreshCache', 'fresh-cache'],
            ['NoOldCache', 'old-cache'],
            ['NoVeryOldCache', 'very-old-cache'],
            ['NoFreshRender', 'fresh-render'],
            ['NoOldRender', 'old-render'],
            ['NoVeryOldRender', 'very-old-render']
        ]},
    'zoom': {
        'options': [None, "Number of HTTP response codes by zoom level", "number", "zoom", "mod_tile.zoom", "line"],
        'lines': [
            ['NoRespZoom00', 'zoom00'],
            ['NoRespZoom01', 'zoom01'],
            ['NoRespZoom02', 'zoom02'],
            ['NoRespZoom03', 'zoom03'],
            ['NoRespZoom04', 'zoom04'],
            ['NoRespZoom05', 'zoom05'],
            ['NoRespZoom06', 'zoom06'],
            ['NoRespZoom07', 'zoom07'],
            ['NoRespZoom08', 'zoom08'],
            ['NoRespZoom09', 'zoom09'],
            ['NoRespZoom10', 'zoom10'],
            ['NoRespZoom11', 'zoom11'],
            ['NoRespZoom12', 'zoom12'],
            ['NoRespZoom13', 'zoom13'],
            ['NoRespZoom14', 'zoom14'],
            ['NoRespZoom15', 'zoom15'],
            ['NoRespZoom16', 'zoom16'],
            ['NoRespZoom17', 'zoom17'],
            ['NoRespZoom18', 'zoom18'],
            ['NoRespZoom19', 'zoom19'],
            ['NoRespZoom20', 'zoom20'],
        ]},
}

class Service(UrlService):
    def __init__(self, configuration=None, name=None):
        UrlService.__init__(self, configuration=configuration, name=name)
        self.url = self.configuration.get('url', "http://127.0.0.1/mod_tile")
        self.order = ORDER
        self.definitions = CHARTS

    def check(self):
        netloc = urlparse(self.url).netloc.rpartition(':')
        if netloc[1] == ':': port = netloc[2]
        else: port = 80        
        return UrlService.check(self)

    def _get_data(self):
        """
        Format data received from http request
        :return: dict
        """
        try:
            raw = self._get_raw_data().split("\n")
        except AttributeError:
            return None
        data = {}
        for row in raw:
            tmp = row.split(":")
            try:
                data[tmp[0]] = int(tmp[1])
            except (IndexError, ValueError):
                pass
        if len(data) == 0:
            return None
        return data

