# -*- coding: utf-8 -*-
# Description: render netdata python.d module
# Author: Didier Fabert (tartare)

from base import SimpleService

# default module values (can be overridden per job in `config`)
# update_every = 2
priority = 60000
retries = 60
update_every = 1

# charts order (can be overridden if you want less charts, or different order)
ORDER = ['metatile', 'queue', 'timequeue', 'zoom', 'timezoom']

CHARTS = {
    'metatile': {
        'options': [None, "Number of metatiles being rendered by renderd", "number", "tiles", "render.tiles", "line"],
        'lines': [
            ['ReqLowRendered', 'lowprio'],
            ['ReqPrioRendered', 'highprio'],
            ['DirtyRendered', 'dirty'],
            ['ReqBulkRendered', 'bulk'],
            ['DropedRequest', 'droped'],
            ['ReqRendered', 'all']
            
        ]},
    'queue': {
        'options': [None, "Priority request Queue", "number", "queues", "render.queue", "line"],
        'lines': [
            ['ReqLowQueueLength', 'lowprio'],
            ['ReqPrioQueueLength', 'highprio'],
            ['DirtQueueLength', 'dirty'],
            ['ReqBulkQueueLength', 'bulk'],
            ['ReqQueueLength', 'all'] 
        ]},
    'timequeue': {
        'options': [None, "Renderd time spent by queue", "second", "queues", "render.timequeue", "line"],
        'lines': [
            ['TimeLowRendered', 'lowprio'],
            ['TimePrioRendered', 'highprio'],
            ['TimeDirtyRendered', 'dirty'],
            ['TimeBulkRendered', 'bulk'],
            ['TimeRendered', 'all'] 
        ]},
    'zoom': {
        'options': [None, "Number of metatiles being rendered by renderd", "number", "zoom", "render.zoom", "line"],
        'lines': [
            ['ZoomRendered00', 'zoom00'],
            ['ZoomRendered01', 'zoom01'],
            ['ZoomRendered02', 'zoom02'],
            ['ZoomRendered03', 'zoom03'],
            ['ZoomRendered04', 'zoom04'],
            ['ZoomRendered05', 'zoom05'],
            ['ZoomRendered06', 'zoom06'],
            ['ZoomRendered07', 'zoom07'],
            ['ZoomRendered08', 'zoom08'],
            ['ZoomRendered09', 'zoom09'],
            ['ZoomRendered10', 'zoom10'],
            ['ZoomRendered11', 'zoom11'],
            ['ZoomRendered12', 'zoom12'],
            ['ZoomRendered13', 'zoom13'],
            ['ZoomRendered14', 'zoom14'],
            ['ZoomRendered15', 'zoom15'],
            ['ZoomRendered16', 'zoom16'],
            ['ZoomRendered17', 'zoom17'],
            ['ZoomRendered18', 'zoom18'],
            ['ZoomRendered19', 'zoom19'],
            ['ZoomRendered20', 'zoom20']
        ]},
    'timezoom': {
        'options': [None, "Amount of time renderd has spent rendering tiles of a given zoom", "second", "zoom", "render.timezoom", "line"],
        'lines': [
            ['TimeRenderedZoom00', 'zoom00'],
            ['TimeRenderedZoom01', 'zoom01'],
            ['TimeRenderedZoom02', 'zoom02'],
            ['TimeRenderedZoom03', 'zoom03'],
            ['TimeRenderedZoom04', 'zoom04'],
            ['TimeRenderedZoom05', 'zoom05'],
            ['TimeRenderedZoom06', 'zoom06'],
            ['TimeRenderedZoom07', 'zoom07'],
            ['TimeRenderedZoom08', 'zoom08'],
            ['TimeRenderedZoom09', 'zoom09'],
            ['TimeRenderedZoom10', 'zoom10'],
            ['TimeRenderedZoom11', 'zoom11'],
            ['TimeRenderedZoom12', 'zoom12'],
            ['TimeRenderedZoom13', 'zoom13'],
            ['TimeRenderedZoom14', 'zoom14'],
            ['TimeRenderedZoom15', 'zoom15'],
            ['TimeRenderedZoom16', 'zoom16'],
            ['TimeRenderedZoom17', 'zoom17'],
            ['TimeRenderedZoom18', 'zoom18'],
            ['TimeRenderedZoom19', 'zoom19'],
            ['TimeRenderedZoom20', 'zoom20']
        ]},
}

class Service(SimpleService):
    def __init__(self, configuration=None, name=None):
        SimpleService.__init__(self, configuration=configuration, name=name)
        self.order = ORDER
        self.definitions = CHARTS
        self.statsfile = self.configuration.get('statsfile', "/run/renderd/renderd.stats")

    def check(self):
        raw_data = self._get_raw_data()
        if not raw_data:
            self.error('Cant read stats data from %s' % (self.statsfile))
            return False  
        return True

    def _get_raw_data(self):
        """
        Read data from /run/renderd/renderd.stats
        :return: str
        """
        try:
            with open(self.statsfile, 'rt') as statsfile:
                raw_result = statsfile.read()
        except Exception:
            return None
        else:
            return raw_result

    def _get_data(self):
        """
        Parse data from _get_raw_data()
        :return: dict
        """
        try:
            raw = self._get_raw_data().split("\n")
        except AttributeError:
            return None
        data = {}
        for row in raw:
            tmp = row.split(":")
            try:
                data[tmp[0]] = int(tmp[1])
            except (IndexError, ValueError):
                pass
        if len(data) == 0:
            return None
        return data
